"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Thrown when a file has an incorrect JSON syntax. Contains filename and file content.
 */
class FileParseError extends SyntaxError {
    constructor(message, filename, content) {
        super(message);
        this.filename = filename;
        this.content = content;
        // Maintenir dans la pile une trace adéquate de l'endroit où l'erreur a été déclenchée (disponible seulement en V8)
        if (Error.captureStackTrace) {
            Error.captureStackTrace(this, FileParseError);
        }
        this.name = 'FileParseError';
    }
}
exports.FileParseError = FileParseError;
/**
 * Thrown when tweet file is incorrect. Property `extract` contain one tweet.
 */
class TweetFileError extends TypeError {
    constructor(message, extract, original_stack) {
        super(message);
        this.extract = extract;
        this.original_stack = original_stack;
        if (Error.captureStackTrace) {
            Error.captureStackTrace(this, TweetFileError);
        }
        this.name = 'TweetFileError';
    }
}
exports.TweetFileError = TweetFileError;
/**
 * Thrown when DM file is incorrect. Property `extract` contain one dm.
 */
class DirectMessageParseError extends TypeError {
    constructor(message, extract, original_stack) {
        super(message);
        this.extract = extract;
        this.original_stack = original_stack;
        if (Error.captureStackTrace) {
            Error.captureStackTrace(this, DirectMessageParseError);
        }
        this.name = 'DirectMessageParseError';
    }
}
exports.DirectMessageParseError = DirectMessageParseError;
/**
 * Thrown when Profile file is incorrect. Property `extract` contain the profile.
 */
class ProfileFileError extends TypeError {
    constructor(message, extract, original_stack) {
        super(message);
        this.extract = extract;
        this.original_stack = original_stack;
        if (Error.captureStackTrace) {
            Error.captureStackTrace(this, ProfileFileError);
        }
        this.name = 'ProfileFileError';
    }
}
exports.ProfileFileError = ProfileFileError;
/**
 * Thrown when Account file is incorrect. Property `extract` contain the profile.
 */
class AccountFileError extends TypeError {
    constructor(message, extract, original_stack) {
        super(message);
        this.extract = extract;
        this.original_stack = original_stack;
        if (Error.captureStackTrace) {
            Error.captureStackTrace(this, AccountFileError);
        }
        this.name = 'AccountFileError';
    }
}
exports.AccountFileError = AccountFileError;
class FileNotFoundError extends ReferenceError {
    constructor(message, filename) {
        super(message);
        this.filename = filename;
        if (Error.captureStackTrace) {
            Error.captureStackTrace(this, FileNotFoundError);
        }
        this.name = 'FileNotFoundError';
    }
}
exports.FileNotFoundError = FileNotFoundError;
